@@ -12,7 +12,7 @@ function(Ps, q = 1, PhyloTree, Normalize = TRUE, CheckArguments = TRUE)
       phyTree <- PhyloTree
     } else {
       if (inherits(PhyloTree, "hclust")) {
-        phyTree <- hclust2phylog(PhyloTree)
+        phyTree <- ade4::hclust2phylog(PhyloTree)
       } else {
         stop("PhyloTree must be an object of class phylog or hclust")
       }
